#ifndef __BOARD_SIGN_API_H__
#define __BOARD_SIGN_API_H__

#ifdef __cplusplus
extern "C" {
#endif

typedef unsigned short ushort;

// 手写笔信息
typedef struct tagTOUCH_INFO {
	int x;			// X坐标
	int y;			// Y坐标
	int pressure;	// 压感值
	int btnId;		//3寸/5寸屏的“确认”、“重签”、“取消”按钮。10寸手写屏和手写板：btnId = -1
} TOUCH_INFO;

// 设备信息
typedef struct tagDEVICE_INFO {
	char VendorName[56];	// 厂家名称
	char ProductName[32];	// 设备型号
	char DllVersion[12];	// Unicom_Sign.dll版本号 如 2.1
	RECT MonitorBounds;		// 屏幕笔迹坐标范围
	int PressureLevel;		// 压感级别（512、1024、2048）
	int DeviceType;			//区分手写板、10寸手写屏、3寸/5寸签名板0：10寸手写屏 1： 3/5寸签名屏（带小屏签字板）2：手写板
	ushort  vendorID;		//设备VID
	ushort productID;		//设备PID
	char serial[20];		//设备唯一序列号，以’\0’结尾
} DEVICE_INFO;

// 设备状态侦听器回调函数
typedef void(CALLBACK *DEVICE_STATUS_FUNC)(int status);//设备当前状态：0，可用；其他值，不可用

// 手写笔信息侦听器回调函数
typedef int(CALLBACK *TOUCH_INFO_FUNC)(TOUCH_INFO info);


/**
*	描述：获取设备状态。
*	返回值：0：设备可用；其他值：设备不可用。
*	输入：无。
*/
int WINAPI GetDeviceStatus();

/**
*	描述：获取设备的信息。
*	返回值：0：成功；其他值：失败。可以通过GetErrorMessage得到描述。
*	输入1：设备信息结构体，内存由调用方分配。
*/
int WINAPI GetDeviceInfo(DEVICE_INFO *devInfo);

/**
	*
	* @param devInfo
	* @return
	*/
int WINAPI GetScreenDeviceInfo(SCREEN_DEVICE_INFO *devInfo);


/**
*	描述：注册设备状态更改的回调函数。
*	返回值：0：成功；其他值：失败。可以通过GetErrorMessage得到描述。
*	输入1：回调函数指针
*/
int WINAPI RegisterDeviceStatusCallBack(DEVICE_STATUS_FUNC func);

/**
*	描述：注销设备状态更改的回调函数，与RegisterDeviceStatusCallBack配对使用。
*	返回值：0：成功；其他值：失败。可以通过GetErrorMessage得到描述。
*	输入1：回调函数指针。
*/
int WINAPI UnregisterDeviceStatusCallBack(DEVICE_STATUS_FUNC func);

/**
*	描述：注册手写笔信息回调函数。
*	返回值：0：成功；其他值：失败。可以通过GetErrorMessage得到描述。
*	输入1：回调函数指针。
*/
int  WINAPI RegisterTouchInfoCallBack(TOUCH_INFO_FUNC func);

/**
*	描述：注销手写笔信息回调函数。与RegisterTouchInfoCallBack配对使用。
*	返回值：0：成功；其他值：失败。可以通过GetErrorMessage得到描述。
*	输入1：回调函数指针。
*/
int WINAPI UnregisterTouchInfoCallBack(TOUCH_INFO_FUNC func);

/**
	描述：获取错误码的描述。
	返回值：无。
	输入1：errorCode：错误码。
	输入2：errorMsg：输出的错误描述，内存由调用方分配，长度512字节。
*/
void  WINAPI GetErrorMessage(int errorCode, char* errorMsg);

#ifdef __cplusplus
}
#endif

#endif

